@@ -6,7 +6,7 @@ Kernels
 </category>
 
 <name>
-MX 4.19 no-pae
+MX 4.19.0-6 no-pae
 </name>
 
 <description>
@@ -67,18 +67,18 @@ MX 4.19 no-pae
 </preinstall>
 
 <install_package_names>
-linux-image-4.19.0-5-686-unsigned
-linux-headers-4.19.0-5-686
+linux-image-4.19.0-6-686-unsigned
+linux-headers-4.19.0-6-686
 </install_package_names>
 
 
 <postinstall>
-/usr/share/mx-packageinstaller-pkglist/rebuild_dkms_packages.sh linux-image-4.19.0-5-686-unsigned
+/usr/share/mx-packageinstaller-pkglist/rebuild_dkms_packages.sh linux-image-4.19.0-6-686-unsigned
 </postinstall>
 
 
 <uninstall_package_names>
-linux-image-4.19.0-5-686-unsigned
-linux-headers-4.19.0-5-686
+linux-image-4.19.0-6-686-unsigned
+linux-headers-4.19.0-6-686
 </uninstall_package_names>
 </app>
